@@ -1,13 +1,12 @@
 ## ----setup, echo = FALSE--------------------------------------------------------------------------
 knitr::opts_chunk$set(error = TRUE, cache = FALSE, eval = TRUE, out.width = "100%")
-httr::set_config(httr::config(ssl_verifypeer = FALSE))
 options(width=100)
 
 ## ----useEnsembl-----------------------------------------------------------------------------------
 library(biomaRt)
 ensembl <- useEnsembl(biomart = "genes", dataset = "hsapiens_gene_ensembl")
 
-## ---- listEnsembl---------------------------------------------------------------------------------
+## ----listEnsembl----------------------------------------------------------------------------------
 listEnsembl()
 
 ## ----ensembl1-------------------------------------------------------------------------------------
@@ -27,26 +26,26 @@ searchDatasets(mart = ensembl, pattern = "hsapiens")
 ensembl <- useDataset(dataset = "hsapiens_gene_ensembl", mart = ensembl)
 
 ## ----ensembl4, eval = FALSE-----------------------------------------------------------------------
-#  ensembl <- useEnsembl(biomart = "genes", dataset = "hsapiens_gene_ensembl")
+# ensembl <- useEnsembl(biomart = "genes", dataset = "hsapiens_gene_ensembl")
 
-## ---- mirrors, eval = FALSE-----------------------------------------------------------------------
-#  ensembl <- useEnsembl(biomart = "ensembl",
-#                     dataset = "hsapiens_gene_ensembl",
-#                     mirror = "useast")
+## ----mirrors, eval = FALSE------------------------------------------------------------------------
+# ensembl <- useEnsembl(biomart = "ensembl",
+#                    dataset = "hsapiens_gene_ensembl",
+#                    mirror = "useast")
 
 ## ----archiveMarts, echo = TRUE, eval = TRUE-------------------------------------------------------
 listEnsemblArchives()
 
 ## ----archiveMarts3, echo = TRUE, eval = TRUE------------------------------------------------------
-listEnsembl(version = 95)
-ensembl95 <- useEnsembl(biomart = 'genes', 
+listEnsembl(version = 110)
+ensembl_110 <- useEnsembl(biomart = 'genes', 
                        dataset = 'hsapiens_gene_ensembl',
-                       version = 95)
+                       version = 110)
 
 ## ----listEnsemblGenomes---------------------------------------------------------------------------
 listEnsemblGenomes()
 
-## ---- plants1-------------------------------------------------------------------------------------
+## ----plants1--------------------------------------------------------------------------------------
 ensembl_plants <- useEnsemblGenomes(biomart = "plants_mart")
 searchDatasets(ensembl_plants, pattern = "Arabidopsis")
 
@@ -197,7 +196,7 @@ getBM(attributes = c('refsnp_id','allele','chrom_start','chrom_strand'),
       values = list(8, 148350, 148420), 
       mart = snpmart)
 
-## ----getLDS, cache = TRUE-------------------------------------------------------------------------
+## ----getLDS---------------------------------------------------------------------------------------
 human <- useEnsembl("ensembl", dataset = "hsapiens_gene_ensembl")
 mouse <- useEnsembl("ensembl", dataset = "mmusculus_gene_ensembl")
 getLDS(attributes = c("hgnc_symbol","chromosome_name", "start_position"),
@@ -206,11 +205,11 @@ getLDS(attributes = c("hgnc_symbol","chromosome_name", "start_position"),
        attributesL = c("refseq_mrna","chromosome_name","start_position"), 
        martL = mouse)
 
-## ---- ssl-verifypeer, eval = FALSE----------------------------------------------------------------
-#  httr::set_config(httr::config(ssl_verifypeer = FALSE))
+## ----ssl-verifypeer, eval = FALSE-----------------------------------------------------------------
+# setEnsemblSSL(list(ssl_verifypeer = FALSE))
 
-## ---- ssl-cipher-list, eval = FALSE---------------------------------------------------------------
-#  httr::set_config(httr::config(ssl_cipher_list = "DEFAULT@SECLEVEL=1"))
+## ----ssl-cipher-list, eval = FALSE----------------------------------------------------------------
+# setEnsemblSSL(list(ssl_cipher_list = "DEFAULT@SECLEVEL=1"))
 
 ## ----sessionInfo----------------------------------------------------------------------------------
 sessionInfo()
