@@ -1,5 +1,4 @@
 library(biomaRt) 
-library(webmockr)
 
 ## example Mart object
 ex_mart <- Mart(biomart = "ensembl", 
@@ -26,36 +25,25 @@ test_that("useEnsembl() error handling is OK", {
 })
 
 
-test_that("Ensembl mirror selection works", {
-    
-    httr_mock()
-    on.exit(httr_mock(on = FALSE))
-    
-    ## failure when all mirrors are down
-    m_www    <- stub_request("POST", uri_regex = "https://www.ensembl.org/biomart/martservice?redirect=no") |> 
-        to_return(status = 500)
-    m_useast <- stub_request("POST", uri_regex = "https://useast.ensembl.org/biomart/martservice?redirect=no") |> 
-        to_return(status = 500)
-    m_asia   <- stub_request("POST", uri_regex = "https://asia.ensembl.org/biomart/martservice?redirect=no") |> 
-        to_return(status = 500)
-    
-    expect_error(.chooseEnsemblMirror(mirror = NULL), regexp = "Unable to query any Ensembl site") 
-    
-    ## now set www to working and check we end up on that mirror
-    remove_request_stub(m_www)
-    m_www <- stub_request("POST", uri = "https://www.ensembl.org/biomart/martservice?redirect=no") |> 
-        wi_th(
-          headers = list('Accept' = 'application/json, text/xml, application/xml, */*', 'Content-Type' = 'text/plain')
-          ) |>
-        to_return(status = 200)
+with_mock_dir("all_500", {
+  test_that("Ensembl mirror selection works", {
+  
+  expect_error(.chooseEnsemblMirror(mirror = NULL), 
+               regexp = "Unable to query any Ensembl site") 
+  
+  })
+},
+simplify = FALSE)
+
+with_mock_dir("www_OK", {
+  test_that("Ensembl mirror selection works", {
     
     expect_message(.chooseEnsemblMirror(mirror = "useast"), regexp = "unresponsive") |>
-        expect_equal("www")
+      expect_equal("www")
     
-    ## clean up mocking
-    stub_registry_clear()
-    
-})
+  })
+},
+simplify = FALSE)
 
 test_that("Ensembl URLs are constructed correctly", {
   
