@@ -6,14 +6,17 @@ Sys.setenv(BIOMART_CACHE = cache)
 context('listMarts()')
 ###############################
 
-test_that("listMarts returns a data.frame", {
-    
-    ensembl_marts <- listMarts(host = "https://www.ensembl.org")
-    expect_is(ensembl_marts, class = "data.frame")
-    expect_identical(colnames(ensembl_marts),
-                     c("biomart", "version"))
-    
-})
+with_mock_dir("all_200", {
+  test_that("listMarts returns a data.frame", {
+      
+      ensembl_marts <- listMarts(host = "https://www.ensembl.org")
+      expect_is(ensembl_marts, class = "data.frame")
+      expect_identical(colnames(ensembl_marts),
+                       c("biomart", "version"))
+      
+  })
+}, 
+simplify = TRUE)
 
 test_that("Error when archive = TRUE", {
     
