@@ -1,3 +1,5 @@
+library(biomaRt)
+
 cache <- file.path(tempdir(), "biomart_cache_test")
 Sys.setenv(BIOMART_CACHE = cache)
 
@@ -43,7 +45,8 @@ test_that("We find cache for previous query", {
     expect_identical(result, .readFromCache(bfc, hash = hash))
 })
 
-## add an invalid file
+## add an invalid file.  We are only expecting .rds files, and this is a 
+## text file
 tf <- tempfile()
 writeLines(LETTERS, con = tf)
 BiocFileCache::bfcadd(bfc, rname = "invalid-file", fpath = tf)
@@ -55,6 +58,13 @@ test_that("invalid cache entry detected", {
 })
 
 
+## check we can't write multiple entries with the same hash
+test_that("we can't create multiple entries with the same hash", {
+  expect_true(.addToCache(bfc = bfc, result = 1:100, hash = "testing"))
+  expect_false(.addToCache(bfc = bfc, result = 1:100, hash = "testing"))
+})
+
+
 
 test_that("Cache details are printed", {
     expect_message( biomartCacheInfo(),
@@ -66,4 +76,6 @@ test_that("Cache can be cleared", {
     expect_true( file.exists( cache_file ) )
     expect_silent( biomartCacheClear() )
     expect_false( file.exists( cache_file) )
-})
\ No newline at end of file
+})
+
+Sys.unsetenv("BIOMART_CACHE")
